import argparse
from enum import Enum
import sys

import utils.split_pdf as split_pdf
import utils.split_pptx as split_pptx
import utils.merge_docx as merge_docx
import utils.merge_pdf as merge_pdf
import utils.merge_pptx as merge_pptx

class Handlers(Enum):
    SPLIT_PDF = "split_pdf"
    SPLIT_PPTX = "split_pptx"
    SPLIT_DOCX = "split_docx"
    MERGE_DOCX = "merge_docx"
    MERGE_PDF = "merge_pdf"
    MERGE_PPTX = "merge_pptx"

HANDLER_FUNCTIONS = {
    Handlers.SPLIT_PDF.value: split_pdf.main,
    Handlers.MERGE_DOCX.value: merge_docx.main,
    Handlers.SPLIT_PPTX.value: split_pptx.main,
    Handlers.MERGE_PDF.value: merge_pdf.main,
    Handlers.MERGE_PPTX.value: merge_pptx.main,
}

if __name__ == "__main__":
    parser = argparse.ArgumentParser(
        description="Main entry point for file handlers.")
    parser.add_argument(
        "handler",
        type=str,
        choices=[h.value for h in Handlers],
        help="Specify which handler to use."
    )
    args, remaining_args = parser.parse_known_args()
    handler_function = HANDLER_FUNCTIONS.get(args.handler)
    if handler_function:
        handler_function(remaining_args)
    else:
        print(f"Handler '{args.handler}' is not recognized.")
        sys.exit(1)
