import argparse
from pptx import Presentation
import copy

def merge_pptx(input_files: list, output_file: str):
    merged_presentation = Presentation()
    
    if merged_presentation.slides:
        r_id = merged_presentation.slides._sldIdLst[0].rId
        merged_presentation.part.drop_rel(r_id)
        del merged_presentation.slides._sldIdLst[0]
    
    first_pres = Presentation(input_files[0])
    merged_presentation.slide_width = first_pres.slide_width
    merged_presentation.slide_height = first_pres.slide_height
    
    for file_path in input_files:
        pres = Presentation(file_path)
        
        for slide in pres.slides:
            try:
                blank_slide_layout = pres.slide_layouts[12]
            except IndexError:
                blank_slide_layout = pres.slide_layouts[-1]
            
            new_slide = merged_presentation.slides.add_slide(blank_slide_layout)
            
            
            for shp in slide.shapes:
                el = shp.element
                newel = copy.deepcopy(el)
                new_slide.shapes._spTree.insert_element_before(newel, 'p:extLst')
            
            
            for _, value in slide.part.rels.items():
                if "notesSlide" not in value.reltype:
                    new_slide.part.rels._add_relationship(
                        value.reltype,
                        value._target,
                    )
    
    merged_presentation.save(output_file)


def main(args=None):
    parser = argparse.ArgumentParser(
        description="Merge a PPTX into a single PPTX.")
    parser.add_argument(
        '--inputFiles', dest='input_files', nargs='+', required=True,
        help="List of input PPTX document files."
    )
    parser.add_argument("--outputFile", dest="output_file", type=str,
                        default=".", help="Output file path for the merged PPTX.")
    parsed_args = parser.parse_args(args)

    merge_pptx(parsed_args.input_files, parsed_args.output_file)
