import os
import argparse
import pikepdf
import json

def split_pdf(input_pdf_path, output_dir):
    os.makedirs(output_dir, exist_ok=True)
    pdf = pikepdf.open(input_pdf_path)
    split_pdf_paths = []

    for page_num in range(len(pdf.pages)):
        new_pdf_path = os.path.join(output_dir, f"{os.path.splitext(os.path.basename(input_pdf_path))[0]}_{page_num + 1}.pdf")
        split_pdf_paths.append(new_pdf_path)
        new_pdf = pikepdf.new()
        new_pdf.pages.append(pdf.pages[page_num])
        new_pdf.save(new_pdf_path)

    print(json.dumps(split_pdf_paths, indent=2))

    pdf.close()


def main(args=None):
    parser = argparse.ArgumentParser(
        description="Split a PDF into multiple PDFs.")
    parser.add_argument("input_pdf_path", type=str,
                        help="Path to the input PDF file.")
    parser.add_argument("--outputDir", dest="output_dir", type=str,
                        default=".", help="Output directory for the split PDFs.")
    parsed_args = parser.parse_args(args)

    split_pdf(parsed_args.input_pdf_path, parsed_args.output_dir)
