import argparse
import os
from pptx import Presentation
import json

def split_pptx(file: str, dest: str) -> int:
    split_pptx_paths = []
    prs = Presentation(file)
    os.makedirs(dest, exist_ok=True)

    for i in range(len(prs.slides)):
        # Load full presentation again
        pres_copy = Presentation(file)

        # Access slide ID list
        sldIdLst = pres_copy.slides._sldIdLst

        # Remove all slides except the i-th
        to_keep = sldIdLst[i]
        slides_to_remove = [s for s in sldIdLst if s != to_keep]
        for s in slides_to_remove:
            rId = s.rId
            pres_copy.part.drop_rel(rId)
            sldIdLst.remove(s)
        path = os.path.join(dest, f"{os.path.splitext(os.path.basename(file))[0]}_{i + 1}.pptx")
        pres_copy.save(path)
        split_pptx_paths.append(path)

    print(json.dumps(split_pptx_paths, indent=2))

def main(args=None):
    parser = argparse.ArgumentParser(description="Split a PPTX into multiple PPTXs.")
    parser.add_argument("input_pptx_path", type=str, help="Path to the input PPTX file.")
    parser.add_argument("--outputDir", dest="output_dir", type=str, default=".", help="Output directory for the split PPTXs.")
    parsed_args = parser.parse_args(args)

    split_pptx(parsed_args.input_pptx_path, parsed_args.output_dir)